function [] = ComputeStabilityRegion(s,radius)

    % Author:   Martin Neuenhofen
    % Date:     somewhen in 2013
    %
    % This code is distributed without any warranty. The following is only
    % a describtion what the program 'should' do but not necessarily what
    % it actually and only does.
    %
    %   This code plots the stability region of an explicit Runge-Kutta
    %   method of 4*s^2 steps and order 2*s+1.
    %
    
    [A,b,c] = Gauss_Tableau(s);
    
    g = StabPolyCoefficients(A,b,c);
    
    if(nargin < 2 || radius == 0)
        radius  = 8;
    end
    N       = 5e2;
    dr      = 2*radius/N;
    
    x = -radius:dr:radius;
    y = x;
    
    Z = zeros(N+1,N+1);
    
    I = (-1)^0.5;
    s = size(g,2)-1;
    
    parfor i=1:N+1
        for j=1:N+1
            mue = (x(i) + I * y(j)).^([0:1:s]');
            Z(i,j) = g * mue;
        end
    end
    
    Z = abs(Z);
    
    [X,Y] = meshgrid(x,x);
    
    %figure;
    
    pcolor(X,Y,log10(Z'));
    hold on;
    xlabel('Realteil');
    ylabel('Imaginrteil');
    shading flat;
    colormap((jet+white)/2);
    contour(X,Y,Z',[1,1],'black','linewidth',2);
    colorbar;
    plot([0,0],[-radius,radius],'black');
    plot([-radius,radius],[0,0],'black');
    title('Stabilittsgebiet');

end