function [x,omg] = GaussQuadPoints(n)

    % Author:   Martin Neuenhofen
    % Date:     somewhen in 2013
    %
    % This code is distributed without any warranty. The following is only
    % a describtion what the program 'should' do but not necessarily what
    % it actually and only does.
    %
    %   The code gives the weights omg and the points of a Gauss-Legendre
    %   quadrature on the interval [-1,1], consisting of n points and
    %   having order 2*n+1.

    a = 0.5*ones(n  ,1);
    b =    zeros(n-1,1);
    
    
    for k=1:n-1
         b(k,1) = k^2 / (4 * (4*k^2 - 1));
    end
    
    J = gallery('tridiag',b.^0.5,a,b.^0.5);
     
    % MATLAB gives a warning for the following: It says I should use eig.
    %[V,D] = eigs(J,n);
    
    % Matlab gives an eror for the following: Its says for sparse J I
    % should use eigs.
    %[V,D] = eig(J,n);
    
    % It seems eig(s) gives me a waring unless I make the matrix dense.
    % Only the following is accepted but seems to be inefficient to me.
    [V,D] = eig(full(J));
    
    % Notice: Matlab lacks of an efficient tridiag eigensolver.
    x   = 2*diag(D) - 1;
    omg = (2* V(1,:).^2 )';
    
    [x,I]   = sort(x);
    omg     = omg(I,1);
end