function [A,b,c] = Gauss_Tableau(s)

    % Author:   Martin Neuenhofen
    % Date:     somewhen in 2013
    %
    % This code is distributed without any warranty. The following is only
    % a describtion what the program 'should' do but not necessarily what
    % it actually and only does.
    %
    %   This code produces the Butcher tableau of a Gauss-Legendre ODE
    %   solver of s stages. It should have order 2*s+1.
    %

    [xi,omg] = GaussQuadPoints(s);
    
    tau = (xi + 1) / 2;

    b = zeros(1,s);
    
    for i=1:s
        for k=1:s
            b(1,i) = b(1,i) + 0.5 * omg(k) * LagrPoly( i , tau(k) , tau );
        end
    end
    
    A = zeros(s,s);
    
    for i=1:s
        for j=1:s
            for k=1:s
                A(i,j) = A(i,j) + (xi(i)+1)/4 * omg(k) * LagrPoly( j , tau(i) * tau(k) , tau );
            end
        end
    end

    c = tau;

end


function [y] = LagrPoly(j,x,tau)

    y = 1;
    
    n = size(tau,1);
    
    for k=1:j-1
        y = y * ((x-tau(k))/(tau(j)-tau(k)));
    end

    for k=j+1:n
        y = y * ((x-tau(k))/(tau(j)-tau(k)));
    end
end