function [t_neu,x_neu] = SingleStep(x,t,h,ode_func)

    global A b c

    % Author:   Martin Neuenhofen
    % Date:     somewhen in 2013
    %
    % This code is distributed without any warranty. The following is only
    % a describtion what the program 'should' do but not necessarily what
    % it actually and only does.
    %
    %   The code should evaluate the Butcher tablau A b c from the
    %   Gauss-Legrendre ODE solver with a Banach scheme in order to obtain
    %   an explicit method. For a sufficient number of fixed point
    %   iterations the order of accuracy of the fixed point no longer
    %   dominates the order of accuracy of the ODE solver and is thus
    %   2*s+1.
    %   
    %   The step is called as follows:
    %
    %       Provide an ode function [dx] = ode_func(t,x), where dx and x
    %       are column vectors. 
    %       Call in the code:
    %           [t_next,x_next] = SingleStep(x,t,h,@ode_func);
    %

    s = size(b,2);
    p = 2*s;
    
    k = zeros(size(x,1),s);
    
    for counter = 1:2*p
        for i=1:s
            k(:,i) = ode_func(  t + h * c(i)  ,  x + h * ( k * (A(i,:))' )  );
        end
    end
    
    x_neu = x + k * (b' * h);
    t_neu = t + h;
end